#
# spec file for package python-SPARQLWrapper
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# Tests are not compatible with python3
%if 0%{?have_python2}
%bcond_without tests
%else
%bcond_with tests
%endif
Name:           python-SPARQLWrapper
Version:        1.8.0
Release:        2.19
Summary:        SPARQL Endpoint interface to Python
License:        W3C
Group:          Development/Languages/Python
Url:            http://sparql-wrapper.sourceforge.net/
Source:         https://files.pythonhosted.org/packages/source/S/SPARQLWrapper/SPARQLWrapper-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
# Only used during installation
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-2to3
Requires:       python-rdflib >= 4.0
BuildArch:      noarch
%python_subpackages

%description
This is a wrapper around a SPARQL service. It helps in creating the
query URI and, possibly, convert the result into a more manageable
format.

%prep
%setup -q -n SPARQLWrapper-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
python2 test/wrapper_test.py
%endif

%files %{python_files}
%doc README.md AUTHORS.md LICENSE.txt
%{python_sitelib}/SPARQLWrapper/
%{python_sitelib}/SPARQLWrapper-%{version}-py*.egg-info

%changelog
* Wed Jan  3 2018 tchvatal@suse.com
- Make sure to not bail out when building with py3 only
- Do not recommend already required package
* Mon May  8 2017 toddrme2178@gmail.com
- Fix source URL.
* Wed May  3 2017 toddrme2178@gmail.com
- Update to version 1.8.0
  * Updated return formats for not content negotiation situations
  * Included license in the MANIFEST (issue #76)
  * Added explicit support for RDF/XML as allowed format (issue #75)
  * Added proper shebang (issue #78)
  * Moved keepalive as optional dependency (issue #79)
  * Fixed hash check on prefixes (issue #77)
- Fixed epydoc warnings (issue #41)
- Implement single-spec version.
- Fix source URL.
* Mon Sep 12 2016 aplanas@suse.com
- update to version 1.7.6
  * Removed wrong response encoding (issue #70)
  * Authorization header bug when using Python 3 (issue #71)
- additional changes from version 1.7.5
  * Removed pip dependency on setup (issue #69)
- additional changes from version 1.7.4
  * Fixed packaging (issue #66)
- additional changes from version 1.7.3
  * Finally fixed the keepalive issue in all Pyhon versions (issue #65)
  * Removed old JSON layer in favor of the native json module
- additional changes from version 1.7.2
  * Moved to the new keepalive package (issues #53 and #61)
- additional changes from version 1.7.1
  * Fixed build in Python 3.x (issue #57)
- additional changes from version 1.7.0
  * Added support to HTTP Digest Auth Support (issue #45)
  * Improved print_results showing language tag (xml:lang) and datatype
  * Updated to RDFLib 4.x
* Fri Feb 12 2016 olaf@aepfle.de
- Remove BuildRequires python-rdflib to avoid cirular dependency
* Wed May 13 2015 benoit.monin@gmx.fr
- update to version 1.6.4:
  * Fixed unicode problems on setup (issue #42)
- additional changes from version 1.6.3:
  * Fixed unicode problems with urllib in Python 3 (issue #35)
  * Restored SPARQLWrapper2 class (issue #36)
  * Enhanced warning for missing rdflib-jsonld (issue #38)
  * Fixed build system (issue #39)
- additional changes from version 1.6.2:
  * Fixed query type detection with comments (issue #32)
- additional changes from version 1.6.1:
  * Added missing query types (issue #17)
  * Added a new method to the API to select the request method to
    be fully SPARQL 1.1 Protocol compliant (issue #28)
  * Improved the test suite coverage, including support to run the
    tests under Python 3.x (issues #20, #24 and #31)
- additional changes from version 1.6.0:
  * Returning raw response in case of unknown content type returned
  * Fixed some issues with the last version of the SPARQL 1.1
    Update Protocol
  * setQuery() doesn't imply resetQuery() anymore
  * Deprecated addCustomParameter(), addParameter() and
    clearParameter() come to provide all required functionality
  * SPARQLWrapper, QueryResult, Value, Bindings (and classes
    inherited from them) are new-style classes now
  * POST queries are accompanied by full set of parameters now
  * Added rudimentary support for JSON-LD
  * Added proper unit tests without dependencies of external
    endpoints
  * Fixed Python 3 compatibility issues in SmartWrapper module
- require python-rdflib instead of recommending it
- require python-simplejson for SLE11
- add runtime dependencies as build dependencies
- remove the fix of end-of-line encoding: changed upstream
- run the tests during build with wrapper_test.py
- change the documentation files to follow upstream
* Fri Dec  6 2013 toddrme2178@gmail.com
- Initial version (1.5.2)
